<?php
/**
 * XJuiThemeSwitcher class file.
 *
 * @author Stefan Volkmar <volkmar_yii@email.de>
 * @license BSD
 */

/**
 * XJuiThemeSwitcher displays a theme switcher widget.
 *
 * XJuiThemeSwitcher encapsulates the {@link http://docs.jquery.com/UI/Theming/ThemeSwitcher} plugin.
 *
 * To use this widget, you may insert the following code in a view:
 * <pre>
 * <?php
 * $this->widget('ext.themeswitcher.XJuiThemeSwitcher', array(
 *        "htmlOptions"=>array('id'=>'switcher')
 *    ));
 * </pre>
 *
 * @author Stefan Volkmar <volkmar_yii@email.de>
 * @version 1.0
 */

Yii::import('zii.widgets.jui.CJuiWidget');

class XJuiThemeSwitcher extends CJuiWidget
{	
	/**
	 * @var string the name of the container element that contains the theme switcher.
     * Defaults to 'div'.
	 */
	public $tagName = 'div';

	/**
	 * Run this widget.
	 * This method registers necessary javascript and renders the needed HTML code.
	 */
	public function run()
	{
		$id=$this->getId();
		if (isset($this->htmlOptions['id']))
			$id = $this->htmlOptions['id'];
		else
			$this->htmlOptions['id']=$id;

		echo CHtml::openTag($this->tagName,$this->htmlOptions);
		echo CHtml::closeTag($this->tagName);

		$options=$this->getClientOptions();
		Yii::app()->getClientScript()->registerScript(__CLASS__.'#'.$id,"jQuery('#{$id}').themeswitcher($options);");
	}

	/**
	 * Registers the core script files.
	 * This method overrides the parent implementation.
	 */
	protected function registerCoreScripts()
	{
		parent::registerCoreScripts();
        Yii::app()->getClientScript()->registerScriptFile('http://jqueryui.com/themeroller/themeswitchertool/',CClientScript::POS_HEAD);
	}

    /**
	 * @return array the javascript options
	 */
	protected function getClientOptions()
	{

		static $callbackFunctions=array(
            'onOpen',
            'onClose',
            'onSelect'
            );

		$options=$this->options;
        if (empty($options)){
            return '';
        } else {
            foreach($callbackFunctions as $func)
            {
                if (array_key_exists($func, $options))
                    if(is_string($options[$func]) && strncmp($options[$func],'js:',3))
                        $options[$func]='js:'.$options[$func];
            }
        }
		return CJavaScript::encode($options);
	}
}
